@@ -22,8 +22,9 @@ class ZMApi (Base):
 
             - apiurl - the full API URL (example https://server/zm/api)
             - portalurl - the full portal URL (example https://server/zm). Only needed if you are downloading events/images
-            - user - username
-            - password - password
+            - user - username (don't specify if no auth)
+            - password - password (don't specify if no auth)
+            - disable_ssl_cert_check - if True will let you use self signed certs
             - logger - (OPTIONAL) function used for logging. If none specified, a simple logger will be used that prints to console. You could instantiate and connect the :class:`pyzm.helpers.ZMLog` module here if you want to use ZM's logging.
 
             Note: you can connect your own customer logging class to the API in which case all modules will use your custom class. Your class will need to implement some methods for this to work. See :class:`pyzm.helpers.Base.SimpleLog` for method details.
@@ -38,6 +39,7 @@ class ZMApi (Base):
         self.options = options
         
         self.authenticated = False
+        self.auth_enabled = True
         self.access_token = ''
         self.refresh_token = ''
         self.access_token_expires = None
@@ -45,12 +47,18 @@ class ZMApi (Base):
         self.refresh_token_datetime = None
         self.legacy_credentials = None
         self.session = requests.Session()
+        if options.get('disable_ssl_cert_check'):
+            self.session.verify = False
+            self.logger.Debug (1, 'Warning, SSL certificate check has been disbled')
+            from urllib3.exceptions import InsecureRequestWarning
+            requests.packages.urllib3.disable_warnings(category=InsecureRequestWarning)
         self.api_version = None
         self.zm_version = None
         self.zm_tz = None
         
+     
         self._login()
-        
+     
         self.Monitors = Monitors(logger=options.get('logger'),api=self)
         self.Events = None
         self.Configs = Configs(logger=options.get('logger'), api=self)
@@ -123,14 +131,23 @@ class ZMApi (Base):
             if self.options.get('token'):
                 self.logger.Debug(1,'Using token for login [{}]'.format(self.options.get('token')))
                 data = {'token':self.options['token']}
-            else:
+                self.auth_enabled = True
+
+            elif self.options.get('user') and self.options.get('password'):
                 self.logger.Debug (1,'using username/password for login')
                 data={'user': self.options['user'],
                     'pass': self.options['password']
                 }
+                self.auth_enabled = True
 
+            else:
+                self.logger.Debug(1,'Not using auth')
+                self.auth_enabled = False
+                data = {}
+                url = self.api_url + '/host/getVersion.json'
+                
             r = self.session.post(url, data=data)
-            if r.status_code == 401 and self.options['token']:
+            if r.status_code == 401 and self.options.get('token') and self.auth_enabled:
                 self.logger.Debug (1, 'Token auth with refresh failed. Likely revoked, doing u/p login')
                 self.options['token'] = None
                 data={'user': self.options['user'],
@@ -144,19 +161,20 @@ class ZMApi (Base):
             rj = r.json()
             self.api_version = rj.get('apiversion')
             self.zm_version = rj.get('version')
-            if (self._versiontuple(self.api_version) >= self._versiontuple('2.0')):
-                self.logger.Debug(1,'Using new token API')
-                self.access_token = rj.get('access_token','')
-                self.refresh_token = rj.get('refresh_token','')
-                self.access_token_expires = int(rj.get('access_token_expires'))
-                self.refresh_token_expires = int(rj.get('refresh_token_expires'))
-                self.refresh_token_datetime = datetime.datetime.now() + datetime.timedelta(seconds = self.refresh_token_expires)
-                self.logger.Debug (1, 'Refresh token expires on:{} [{}s]'.format(self.refresh_token_datetime, self.refresh_token_expires))
-            else:
-                self.logger.Info('Using old credentials API. Recommended you upgrade to token API')
-                self.legacy_credentials = rj.get('credentials')
-                if (rj.get('append_password') == '1'):
-                    self.legacy_credentials = self.legacy_credentials + self.options['password']
+            if self.auth_enabled:
+                if (self._versiontuple(self.api_version) >= self._versiontuple('2.0')):
+                    self.logger.Debug(1,'Using new token API')
+                    self.access_token = rj.get('access_token','')
+                    self.refresh_token = rj.get('refresh_token','')
+                    self.access_token_expires = int(rj.get('access_token_expires'))
+                    self.refresh_token_expires = int(rj.get('refresh_token_expires'))
+                    self.refresh_token_datetime = datetime.datetime.now() + datetime.timedelta(seconds = self.refresh_token_expires)
+                    self.logger.Debug (1, 'Refresh token expires on:{} [{}s]'.format(self.refresh_token_datetime, self.refresh_token_expires))
+                else:
+                    self.logger.Info('Using old credentials API. Recommended you upgrade to token API')
+                    self.legacy_credentials = rj.get('credentials')
+                    if (rj.get('append_password') == '1'):
+                        self.legacy_credentials = self.legacy_credentials + self.options['password']
             self.authenticated = True
             #print (vars(self.session))
 
@@ -175,6 +193,9 @@ class ZMApi (Base):
             self.logger.Error ('Timezone API not found, relative timezones will be local time')
 
     def get_auth(self):
+        if not self.auth_enabled:
+            return ''
+
         if self._versiontuple(self.api_version) >= self._versiontuple('2.0'):
             return 'token='+self.access_token
         else:
@@ -185,20 +206,21 @@ class ZMApi (Base):
 
     def _make_request(self, url=None, query={}, payload={}, type='get', reauth=True):
         type = type.lower()
-        if self._versiontuple(self.api_version) >= self._versiontuple('2.0'):
-            query['token'] = self.access_token
-            # ZM 1.34 API bug, will be fixed soon
-            self.session = requests.Session()
-    
-        else:
-            # credentials is already query formatted
-            lurl = url.lower()
-            if lurl.endswith('json') or lurl.endswith('/'):
-                qchar = '?'
+        if self.auth_enabled:
+            if self._versiontuple(self.api_version) >= self._versiontuple('2.0'):
+                query['token'] = self.access_token
+                # ZM 1.34 API bug, will be fixed soon
+                # self.session = requests.Session()
+        
             else:
-                qchar = '&'
-            url += qchar + self.legacy_credentials
-            
+                # credentials is already query formatted
+                lurl = url.lower()
+                if lurl.endswith('json') or lurl.endswith('/'):
+                    qchar = '?'
+                else:
+                    qchar = '&'
+                url += qchar + self.legacy_credentials
+                
         try:
             self.logger.Debug(1,'make_request called with url={} payload={} type={} query={}'.format(url,payload,type,query))
             if type=='get':
