@@ -28,6 +28,9 @@ class SimpleLog:
     def Info (self,message, caller=None):
         print ('[INFO] {}'.format( message))
 
+    def Warning (self,message, caller=None):
+        print ('[WARNING] {}'.format( message))
+
     def Error (self,message, caller=None):
         print ('[ERROR] {}'.format(message))
 
@@ -37,4 +40,4 @@ class SimpleLog:
 
     def Panic (self,message, caller=None):
         print ('[PANIC] {}'.format(message))
-        exit(-2)
\ No newline at end of file
+        exit(-2)
